# album

Introduction: [https://album.solutions/](https://album.solutions/)

Documentation: [https://docs.album.solutions/](https://docs.album.solutions/)

## Citation

Albrecht, J.P.\*, Schmidt, D.\*, and Harrington, K., 2021. Album: a
framework for scientific data processing with software solutions of
heterogeneous tools. arXiv preprint arXiv:2110.00601.  
https://arxiv.org/abs/2110.00601

## Developers

- Kyle Harrington, Max Delbrueck Center for Molecular Medicine in the
Helmholtz Association
- Jan Philipp Albrecht, Max Delbrueck Center for Molecular Medicine in
  the Helmholtz Association
- Deborah Schmidt, Max Delbrueck Center for Molecular Medicine in
  the Helmholtz Association
